# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

_SNAKE_TO_CAMEL_CASE_TABLE = {
    "b64_std": "b64Std",
    "b64_url": "b64Url",
    "byte_length": "byteLength",
    "min_lower": "minLower",
    "min_numeric": "minNumeric",
    "min_special": "minSpecial",
    "min_upper": "minUpper",
    "override_special": "overrideSpecial",
    "result_count": "resultCount",
}

_CAMEL_TO_SNAKE_CASE_TABLE = {
    "b64Std": "b64_std",
    "b64Url": "b64_url",
    "byteLength": "byte_length",
    "minLower": "min_lower",
    "minNumeric": "min_numeric",
    "minSpecial": "min_special",
    "minUpper": "min_upper",
    "overrideSpecial": "override_special",
    "resultCount": "result_count",
}
